@@ -1,16 +1,19 @@
 from contextlib import contextmanager
+from callback import Callback
 
 
 @contextmanager
-def managed(sessionClass, auto_flush=False):
+def managed(sessionClass, auto_flush=False, auto_commit=False, callback=None):
     session = sessionClass()
     session.autoflush = auto_flush
-    session.autocommit = False
+    session.autocommit = auto_commit
     try:
         yield session
         session.commit()
     except:
         session.rollback()
+        if isinstance(callback, Callback):
+            callback()
         raise
     finally:
         session.close()
